@@ -76,7 +76,7 @@ class CompanyData(TypedDict):
 class ClientData(TypedDict):  
     """Client data structure for better IDE autocomplete."""
     tipo_doc: int              # REQUIRED: Document type (1=DNI, 6=RUC, etc.)
-    numero_doc: str            # REQUIRED: Document number
+    num_doc: str               # REQUIRED: Document number (Greenter convention)
     razon_social: str          # REQUIRED: Client name
     address: Dict[str, str]    # OPTIONAL: Address data  
     email: str                 # OPTIONAL: Client email
@@ -221,7 +221,7 @@ def create_invoice_data(
         serie: OBLIGATORIO - Serie de la factura (ej: 'F001')
         correlativo: OBLIGATORIO - Número correlativo
         company_data: OBLIGATORIO - Datos de la empresa {'ruc': '...', 'razon_social': '...', 'address': {...}}
-        client_data: OBLIGATORIO - Datos del cliente {'tipo_doc': 6, 'numero_doc': '...', 'razon_social': '...'}
+        client_data: OBLIGATORIO - Datos del cliente {'tipo_doc': 6, 'num_doc': '...', 'razon_social': '...'}
         items: OBLIGATORIO - Lista de items con campos calculados:
             [{'cod_item': '...', 'des_item': '...', 'cantidad': 1, 
               'mto_valor_unitario': float, 'mto_precio_unitario': float,
@@ -263,7 +263,7 @@ def create_invoice_data(
     
     client = Client(
         tipo_doc=client_data['tipo_doc'],
-        numero_doc=client_data['numero_doc'],
+        num_doc=client_data['num_doc'],
         razon_social=client_data['razon_social'],
         address=Address(**client_data['address']) if 'address' in client_data else None
     )
