@@ -100,7 +100,7 @@ class TestHighLevelAPI:
         """Datos de cliente para tests"""
         return {
             'tipo_doc': 6,
-            'numero_doc': '20000000002',
+            'num_doc': '20000000002',
             'razon_social': 'CLIENTE DE PRUEBAS S.A.C.'
         }
         
@@ -257,7 +257,7 @@ class TestHighLevelAPI:
         # Modificar cliente para boleta (DNI)
         cliente_boleta = sample_cliente_data.copy()
         cliente_boleta['tipo_doc'] = 1  # DNI
-        cliente_boleta['numero_doc'] = '12345678'
+        cliente_boleta['num_doc'] = '12345678'
         
         # Crear datos de boleta y enviar
         receipt_data = create_invoice_data(
@@ -435,7 +435,7 @@ class TestHighLevelAPI:
         
         minimal_client_data = {
             'tipo_doc': 6,
-            'numero_doc': '99999999999',
+            'num_doc': '99999999999',
             'razon_social': 'CLIENTE INEXISTENTE S.A.C.'
         }
         
@@ -618,7 +618,7 @@ class TestCompleteWorkflows:
             },
             'cliente': {
                 'tipo_doc': 6,
-                'numero_doc': '20000000002',
+                'num_doc': '20000000002',
                 'razon_social': 'CLIENTE COMPLETO DE PRUEBAS S.A.C.'
             },
             'items': [
@@ -726,7 +726,7 @@ class TestCompleteWorkflows:
             },
             client_data={
                 'tipo_doc': 6,
-                'numero_doc': '20000000002', 
+                'num_doc': '20000000002', 
                 'razon_social': 'CLIENTE MINIMO'
             },
             items=[{
@@ -789,7 +789,7 @@ class TestCompleteWorkflows:
                 },
                 client_data={
                     'tipo_doc': 6,
-                    'numero_doc': '99999999999',  # Cliente extranjero
+                    'num_doc': '99999999999',  # Cliente extranjero
                     'razon_social': 'FOREIGN CUSTOMER INC.'
                 },
                 items=[{
