@@ -61,7 +61,7 @@ class TestNetworkErrorHandling:
             },
             'cliente': {
                 'tipo_doc': 6,
-                'numero_doc': '20000000002',
+                'num_doc': '20000000002',
                 'razon_social': 'CLIENTE PRUEBA'
             },
             'items': [{
